@@ -551,7 +551,7 @@ mouse_settings_themes_populate_store (GtkBuilder *builder)
 
     /* select the active theme in the treeview */
     gtk_tree_view_set_cursor (GTK_TREE_VIEW (treeview), active_path, NULL, FALSE);
-    gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (treeview), active_path, NULL, FALSE, 0.5, 0.0);
+    gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (treeview), active_path, NULL, TRUE, 0.5, 0.0);
     gtk_tree_path_free (active_path);
 
     /* sort the store */
@@ -923,6 +923,10 @@ mouse_settings_device_populate_store (GtkBuilder *builder,
             if (G_UNLIKELY (num_buttons <= 0))
                 continue;
 
+            /* ignore XTEST device */
+            if (g_str_has_prefix (device_info->name, "Virtual core XTEST"))
+                continue;
+
             /* create a valid xfconf device name */
             device_name = mouse_settings_device_xfconf_name (device_info->name);
 
@@ -983,9 +987,7 @@ mouse_settings_device_populate_store (GtkBuilder *builder,
     {
         /* set the treeview model */
         gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
-#if GTK_CHECK_VERSION (2, 12, 0)
         gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (treeview), COLUMN_DEVICE_DISPLAY_NAME);
-#endif
 
         /* icon renderer */
         renderer = gtk_cell_renderer_pixbuf_new ();
@@ -1315,8 +1317,15 @@ main (gint argc, gchar **argv)
                 /* unlock */
                 locked--;
 
-                /* show the dialog */
-                gtk_dialog_run (GTK_DIALOG (dialog));
+                gtk_widget_show (GTK_WIDGET (dialog));
+                g_signal_connect (dialog, "response", G_CALLBACK (gtk_main_quit), NULL);
+
+                /* To prevent the settings dialog to be saved in the session */
+                gdk_set_sm_client_id ("FAKE ID");
+
+                gtk_main ();
+
+                gtk_widget_destroy (GTK_WIDGET (dialog));
             }
             else
             {
@@ -1336,6 +1345,9 @@ main (gint argc, gchar **argv)
                 /* Unlock */
                 locked--;
 
+                /* To prevent the settings dialog to be saved in the session */
+                gdk_set_sm_client_id ("FAKE ID");
+
                 /* Enter main loop */
                 gtk_main ();
             }
